\NeedsTeXFormat{LaTeX2e}
\def\fileversion{v3.0}
\def\filedate{99/07/01}
\def\docdate {92/04/12}
\def\filename{cerncnl.cls}
\ProvidesClass{cerncnl}[\filedate\space CERN LaTeX2e document class (MG)]
\typeout{CERN Document Class `cerncnl' <\filedate>.}
\def\bs{{\tt\char'134}}% backslash
\newcommand{\Lcs}[1]{\mbox{\normalfont\ttfamily\bs#1}}
%% \CheckSum{681}
%% \CharacterTable
%%  {Upper-case    \A\B\C\D\E\F\G\H\I\J\K\L\M\N\O\P\Q\R\S\T\U\V\W\X\Y\Z
%%   Lower-case    \a\b\c\d\e\f\g\h\i\j\k\l\m\n\o\p\q\r\s\t\u\v\w\x\y\z
%%   Digits        \0\1\2\3\4\5\6\7\8\9
%%   Exclamation   \!     Double quote  \"     Hash (number) \#
%%   Dollar        \$     Percent       \%     Ampersand     \&
%%   Acute accent  \'     Left paren    \(     Right paren   \)
%%   Asterisk      \*     Plus          \+     Comma         \,
%%   Minus         \-     Point         \.     Solidus       \/
%%   Colon         \:     Semicolon     \;     Less than     \<
%%   Equals        \=     Greater than  \>     Question mark \?
%%   Commercial at \@     Left bracket  \[     Backslash     \\
%%   Right bracket \]     Circumflex    \^     Underscore    \_
%%   Grave accent  \`     Left brace    \{     Vertical bar  \|
%%   Right brace   \}     Tilde         \~}
%%
%
%\iffalse   % this is a METACOMMENT !
%
%
%
% Style-file `cerncnl' to use with LaTeX v2e
% Copyright (C) 2000 Michel Goossens, all rights reserved.
%
% Copying of this file is authorized only if either
% (1) you make absolutely no changes to your copy, including name, or
% (2) if you do make changes, you name it something other than
%     cerncnl.doc.
% This restriction helps ensure that all styles developed at CERN
% are identical.
%
% Please send bug reports to:
%
%                          Michel Goossens
%                          IT Division
%                          CH-1211 Geneva 23
%                          Switzerland
%                  Email:  <michel.goossens@cern.ch>
%
% \fi
%
% \changes{3.1}{99/04/15}{mg
%   Mods for new 2000 version of CNL (artabstract, authbio)}
% \changes{3.0}{99/07/01}{mg
%   Major overhaul for XML support}
% \changes{1.02}{92/05/11}{mg
%   Small change in l@layout}
% \changes{1.01}{92/04/12}{mg
%   First version of layout for CERN Computer Newsletter}
\@ifundefined{CNLart}{}{\typeout{Style-Option: `cerncnl' already
                          loaded}\endinput}
     \typeout{Style-Option: `cerncnl' \fileversion
         \space\space <\filedate> (M.G.)}
%    \end{macrocode}
%
% We define the {\tt twoside} option and desire Marginpars
% going beyond the page.
%    \begin{macrocode}
\@twosidetrue
\@mparswitchtrue
%    \end{macrocode}
%
% Next the standard {\tt report} style is read as well as one of its
% substyles {\tt rep1?}, where {\tt?} stands for 0, 1 or 2, depending
% on the pointsize of the document.
%    \begin{macrocode}
\LoadClass[twoside]{report}
%    \end{macrocode}
%
% The page layout style is chosen to be {\tt headings}
% (report use by default {\tt plain}).
% As I do not like the uppercasing of the chapter and section
% titles in the running headings, the \Lcs{ps@headings} command
% is changed accordingly (taken from {\tt report.sty}).
%
%    \begin{macrocode}
\def\ps@headings{\let\@mkboth\markboth
\def\@oddfoot{}\def\@evenfoot{}
\def\@oddhead{\textsl{\CNLdate}\hfil\rm -\thepage-\hfil \sl\CNLref}
\def\@evenhead{\hbox{}\sl\CNLref \hfil \rm-\thepage-\hfil\textsl{\CNLdate}}
%\def\chaptermark##1{\markboth{\ifnum \c@secnumdepth>\m@ne
% \thechapter. \ \fi ##1}{}}
}
\ps@headings
%    \end{macrocode}
%
% \subsection{Font definitions}
%
% \subsection{Page parameters}
%
% Global typesize independent page layout parameters for a DIN A4 page
% are defined here.
% The definition of these sizes leaves enough space at the sides of the
% page to also get acceptable results for U.S. folio ({\tt11"$\times$8.5"})
% paper.
%
%    \begin{macrocode}
\setlength{\hoffset}{-1cm} % [AS]
\setlength{\voffset}{-8mm}
\setlength{\textwidth}{177mm}
\setlength{\columnsep}{7mm}
\setlength{\evensidemargin}{0mm}
\setlength{\oddsidemargin}{0mm}
\setlength{\marginparwidth}{0mm}
\setlength{\marginparsep}{0mm}
\setlength{\marginparpush}{0mm}
\setlength{\topmargin}{-5mm}
\setlength{\headheight}{5mm}
\setlength{\headsep}{8mm}
\setlength{\footskip}{5mm}
\setlength{\baselineskip}{13pt}
\setlength{\topskip}{1pt} % [AS]
\setlength{\textheight}{54\baselineskip}
\addtolength{\textheight}{\topskip}
%    \end{macrocode}
%
% \subsection{Titles and headings}
%
% The chapter titles of Lamport really are ways too large.
% Therefore we rebuild the heading part of the \Lcs{chapter}
% and \Lcs{chapter*} commands.
%    \begin{macrocode}
 
\renewcommand{\chapter}{\clearpage
                    \global\@topnum\z@
                    \@afterindentfalse
                    \secdef\@chapter\@schapter}
 
\def\@makechapterhead#1{             % Heading for \chapter command
  { \centering
      \LARGE\bf \thechapter.\ #1\par
    \vskip 5mm                      % Space between title and text.
  } }
 
\def\@makeschapterhead#1{             % Heading for \chapter command
  { \centering
      \LARGE\bf #1\par
    \vskip 5mm                      % Space between title and text.
  } }
%    \end{macrocode}
%
% The other section levels are defined with the help of the
% \Lcs{@startsection} command, defined in \LaTeX{} as follows:
%
% \begin{verbatim}
% \@startsection {NAME}{LEVEL}{INDENT}{BEFORESKIP}{AFTERSKIP}{STYLE}
%            optional * [ALTHEADING]{HEADING}
%    Generic command to start a section.
%    NAME       : e.g., 'subsection'
%    LEVEL      : a number, denoting depth of section -- e.g., ?=1,
%                 section = 2, etc.  A section number will be printed if
%                 and only if LEVEL < or = the value of the secnumdepth
%                 counter.
%    INDENT     : Indentation of heading from left margin
%    BEFORESKIP : Absolute value = skip to leave above the heading.
%                 If negative, then paragraph indent of text following
%                 heading is suppressed.
%    AFTERSKIP  : if positive, then skip to leave below heading,
%                       else - skip to leave to right of run-in heading.
%    STYLE      : commands to set style
%  If '*' missing, then increments the counter.  If it is present, then
%  there should be no [ALTHEADING] argument.  A sectioning command
%  is normally defined to \@startsection + its first six arguments.
% \end{verbatim}
%
%    \begin{macrocode}
\renewcommand{\section}{\@startsection {section}{1}{\z@}%
                                   {-2ex \@plus -1ex \@minus -.2ex}%
                                   {2.ex \@plus.2ex}%
                                   {\reset@font\centering\large\bfseries}}
\renewcommand{\subsection}{\@startsection{subsection}{2}{\z@}%
                                     {-2.ex\@plus -1ex \@minus -.2ex}%
                                     {1.5ex \@plus .2ex}%
                                     {\reset@font\raggedright\large\bfseries}}
\renewcommand{\subsubsection}{\@startsection{subsubsection}{3}{\z@}%
                                     {-2.ex\@plus -1ex \@minus -.2ex}%
                                     {1.5ex \@plus .2ex}%
                                     {\reset@font\raggedright\normalsize\bfseries}}
\renewcommand{\paragraph}{\@startsection{paragraph}{4}{\z@}%
                                    {2ex \@plus1ex \@minus.2ex}%
                                    {-1em}%
                                    {\reset@font\normalsize\bfseries}}
\renewcommand{\subparagraph}{\@startsection{subparagraph}{5}{\parindent}%
                                       {2ex \@plus1ex \@minus .2ex}%
                                       {-1em}%
                                      {\reset@font\normalsize\bfseries}}
%    \end{macrocode}
%
\renewcommand{\l@chapter}[2]{%
    \addpenalty{-\@highpenalty}%
    \vskip 0.5em \@plus\p@
    \setlength\@tempdima{1.5em}%
    \begingroup
      \parindent \z@ \rightskip \@pnumwidth
      \parfillskip -\@pnumwidth
      \leavevmode \bfseries
      \advance\leftskip\@tempdima
      \hskip -\leftskip
      #1\nobreak\hfil \nobreak\hb@xt@\@pnumwidth{\hss #2}\par
      \penalty\@highpenalty
    \endgroup}
\renewcommand{\l@section}{\@dottedtocline{1}{1.5em}{2.3em}}
% \section{Array building commands}
%
% In order to profit fully of the work of F. Mittelbach,
% his {\tt array} style file is by default included
% and some of its style parameters are defined.
%
%    \begin{macrocode}
\RequirePackage{array}
\extrarowheight0pt
\arrayrulewidth.5pt
%    \end{macrocode}
 
\def\endash{--}
\def\emdash{\endash-}
\def\thinskip{\hskip 0.16667em\relax}
\def\d@sh#1#2{\unskip#1\thinskip#2\thinskip\ignorespaces}
\def\dash{\d@sh\nobreak\endash}
\def\Dash{\d@sh\nobreak\emdash}
 
\let\CNLart\section
\def\CNLaut#1{\begin{center}\large\it#1\end{center}}
\def\and{{\upshape and}}
\def\CNLkey#1{}
\newenvironment{artabstract}%
  {\begingroup\itshape{\bf Abstract}\par}%
  {\endgroup\par}
\newenvironment{authbio}%
  {\par{\bf About the author(s):}\space\begingroup\itshape}%
  {\endgroup\par}
%
% \LaTeX{} is known for its poor handling of floats.
% Two enviroments {\tt Tabhere} and {\tt Fighere} provide the needed
% functionality of handling the caption material correctly in the
% case of a table and a figure respectively, in both cases forcing
% at the same time the material to be placed {\bf here}, i.e. no
% float is generated.
%    \begin{macrocode}
\newenvironment{Tabhere}%
     {\par\leavevmode\def\@captype{table}}{\par}
\newenvironment{Fighere}%
     {\par\leavevmode\def\@captype{figure}}{\par}
%    \end{macrocode}
%
% While we are at it, we refine the {\tt caption} command a little,
% then go on to tailor the titles for the table of contents,
% the list of tables and figures, and the leaders in the latter two.
%
%    \begin{macrocode}
\setlength\abovecaptionskip{10\p@}
\setlength\belowcaptionskip{5\p@}
\renewcommand{\tableofcontents}{\@starttoc{toc}}
%    \end{macrocode}
%
% \subsection{Simple text generating commands}
%
%    \begin{macrocode}
\newcommand{\Example}{\par{\bf Example:}\par}% Example
\newcommand{\Examples}{\par{\bf Examples:}\par}% Examples
% The command \@minisanitize changes the catcode of $ & # ^ _ % ~ % to other
% except for braces to 'other'.  It it used by many commands in cernman.sty
% this command should only be executed within a group, or chaos will ensue.
 
\def\@minisanitize{\@makeother\$\@makeother\&%
\@makeother\#\@makeother\^\@makeother\_\@makeother\%\@makeother\~}
\def\Lit{\begingroup\@minisanitize\@Lit}
\def\@Lit#1{\tt#1\endgroup}%  Literal string
%\newcommand{\Ucom}[1]{{\tt\underline{#1}}}% User command to be typed
\def\Command#1{{\tt#1}}% Command
\def\Param#1{{\tt#1}}% Parameter
%    \end{macrocode}
%
%    \begin{macrocode}
\newcommand{\Bbfm}{\mbox{\boldmath}}
\newcommand{\Ebfm}{\mbox{\unboldmath}}
\newcommand{\Dstm}{\displaystyle}
\newcommand{\Tstm}{\textstyle}
\newcommand{\Sstm}{\scriptstyle}
\newcommand{\SSstm}{\scriptscriptstyle}
%\newcommand{\bs}{{\tt\char'134}}% backslash
% Non straightforward characters
\newcommand{\amp}{{\tt\char'046}}
\newcommand{\apos}{{\tt\char'023}}
%\newcommand{\ast}{{\tt\char'052}}
\newcommand{\bsol}{{\tt\char'134}}
%\newcommand{\circ}{{\tt\char'136}}
%\newcommand{\colon}{{\tt\char'072}}
\newcommand{\commat}{{\tt\char'100}}
\newcommand{\dollar}{{\tt\char'044}}
\newcommand{\excl}{{\tt\char'041}}
\newcommand{\us}{{\tt\char'137}}%underscore
\newcommand{\hyphen}{{\tt\char'055}}
\newcommand{\lcub}{{\tt\char'173}}
\newcommand{\lpar}{{\tt\char'050}}
\newcommand{\lsqb}{{\tt\char'133}}
\newcommand{\lsquo}{{\tt\char'022}}
\newcommand{\num}{{\tt\char'043}}
\newcommand{\percnt}{{\tt\char'045}}
\newcommand{\period}{{\tt\char'056}}
\newcommand{\quest}{{\tt\char'077}}
\newcommand{\quot}{{\tt\char'042}}
\newcommand{\rcub}{{\tt\char'175}}
\newcommand{\rpar}{{\tt\char'051}}
\newcommand{\rsqb}{{\tt\char'135}}
\newcommand{\rsquo}{{\tt\char'023}}
\newcommand{\semi}{{\tt\char'073}}
\newcommand{\sol}{{\tt\char'047}}
%\newcommand{\tilde}{{\tt\char'176}}
\newcommand{\verbar}{{\tt\char'174}}
\newcommand{\sbl}{{\tt\char'040}}% significant blank
\let\at=\commat\let\atsign=\commat
\def\bs{{\tt\upshape\char'134}}\let\bslash=\bs
\def\lab{{\tt\upshape\char'074}}
\def\rab{{\tt\upshape\char'076}}
\let\percent\percnt
\let\lcb\lcub
\let\rcb\rcub
\let\lsb\lsqb
\let\rsb\rsqb
\let\US\us
 
\newcommand{\Rule}{\rule[-.9ex]{0ex}{3.1ex}}
 
%    \end{macrocode}
%
% \subsection{Definition of extended list environments}
%
%    \begin{macrocode}
\newenvironment{DLtt}[1]% The parameter is the width of the term
                        {\def\DLH{\tt}\begin{DLgen}{#1}}{\end{DLgen}}
\newenvironment{DL}[1]% The parameter is the width of the term
                        {\def\DLH{\bf}\begin{DLgen}{#1}}{\end{DLgen}}
\newenvironment{DLttc}[1]% The parameter is the width of the term
                        {\def\DLH{\tt}\begin{DLgenc}{#1}}{\end{DLgenc}}
\newenvironment{DLc}[1]% The parameter is the width of the term
                        {\def\DLH{\bf}\begin{DLgenc}{#1}}{\end{DLgenc}}
\newenvironment{DLgen}[1]{% Generic description list
    \begin{list}{\phantom{\DLH#1}}%
   {\settowidth{\labelwidth}{\DLH#1\quad}% define global width
    \setlength{\leftmargin}{\labelwidth}%  set global width
    \setlength{\itemindent}{0pt}%          set global width
    \setlength{\labelsep}{0pt}%            horizontal sep. term/item
    \setlength{\itemsep}{1pt}%             vertical sep. item/item
    \setlength{\parsep}{0pt}%              vertical sep. 2 pars in item
    \setlength{\topsep}{.2\baselineskip}%  vertical sep. text/list
    \renewcommand{\makelabel}[1]{\DLH##1\ \hfil}}}% parameter from item
{\end{list}}% ***** end of environment{DLtt}
\newenvironment{DLgenc}[1]{% Generic dense description list
\begin{list}{\phantom{\DLH#1}}%
   {\settowidth{\labelwidth}{\DLH#1\quad}% define global width
    \setlength{\leftmargin}{\labelwidth}%  set global width
    \setlength{\itemindent}{0pt}%          Everything else 0pt
    \labelsep0pt\itemsep0pt\topsep0pt\partopsep0pt\parskip0pt\parsep0pt
    \renewcommand{\makelabel}[1]{\DLH##1\hfil}}}% get parameter from item
{\end{list}}% ***** end of environment{DLttc}
\newcounter{cOL}
\newenvironment{OL}{% Ordered list
\begin{list}{\hfill{\bf\arabic{cOL}}\hskip6pt}%
   {\setlength{\labelsep}{0pt}% horizontal separation between term and item
    \setlength{\itemsep}{2pt}% vertical separation between two items
    \setlength{\parsep}{0pt}% vertical separation two paragraphs in an item
    \setlength{\topsep}{.5\baselineskip}% vertical separation text/list
    \usecounter{cOL}}}{\end{list}}
\newenvironment{OLc}{% Dense order list
\begin{list}{\hfill{\bf\arabic{cOL}}\hskip6pt}%
   {\setlength{\labelsep}{0pt}% horizontal separation between term and item
    \labelsep0pt\itemsep0pt\topsep0pt\partopsep0pt\parskip0pt\parsep0pt
    \usecounter{cOL}}}{\end{list}}
\newenvironment{UL}{% Unnumbered list
\begin{list}{}
   {\setlength{\labelsep}{0pt}% horizontal separation between term and item
    \setlength{\itemsep}{2pt}% vertical separation between two items
    \setlength{\parsep}{0pt}% vertical separation two paragraphs in an item
    \setlength{\topsep}{.5\baselineskip}% vertical separation text/list
    \renewcommand{\makelabel}{\hfill$\bullet$\hskip6pt}}}%
{\end{list}}
\newenvironment{ULc}{% Dense unnumbered list
\begin{list}{}{%
    \labelsep0pt\itemsep0pt\topsep0pt\partopsep0pt\parskip0pt\parsep0pt
    \renewcommand{\makelabel}{\hfill$\bullet$\hskip6pt}}}%
{\end{list}}
%    \end{macrocode}
%
 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 
\RequirePackage{multicol}
\RequirePackage{textcomp}

\let\Otemize =\itemize
\let\Onumerate =\enumerate
\let\Oescription =\description
% Zero the vertical spacing parameters
\def\Nospacing{\itemsep=0pt\topsep=0pt\partopsep=0pt\parskip=0pt\parsep=0pt}
% Redefine the environments in terms of the original values
\newenvironment{Itemize}{\Otemize\Nospacing}{\endlist}
\newenvironment{Enumerate}{\Onumerate\Nospacing}{\endlist}
\newenvironment{Description}{\Oescription\Nospacing}{\endlist}

\renewenvironment{thebibliography}[1]
     {\subsection*{\bibname
        \@mkboth{\MakeUppercase\bibname}{\MakeUppercase\bibname}}%
      \list{\@biblabel{\@arabic\c@enumiv}}%
           {\settowidth\labelwidth{\@biblabel{#1}}%
            \leftmargin\labelwidth
            \advance\leftmargin\labelsep
            \@openbib@code
            \usecounter{enumiv}%
            \let\p@enumiv\@empty
            \renewcommand\theenumiv{\@arabic\c@enumiv}}%
      \sloppy\clubpenalty4000\widowpenalty4000%
      \sfcode`\.\@m\Nospacing}
     {\def\@noitemerr
       {\@latex@warning{Empty `thebibliography' environment}}%
      \endlist}

\parindent0pt
\parskip 3pt plus 1pt

\def\Dominisanitise{%%%%% Sanitize most characters %%%%%
\catcode`\_=12\def\_{\ifmmode\sb\else_\fi}
\catcode`\^=12\def\^{\ifmmode\sp\else^\fi}% return ^ to subscript
                                          % inside math
\catcode`\$=12\catcode`\~=12\catcode`\&=12\catcode`\#=12\catcode`\%=12\relax
}

\RequirePackage{fancyvrb}
\DefineVerbatimEnvironment{verbatim}{Verbatim}
                          {fontsize=\normalsize,xleftmargin=\parindent}
\DefineVerbatimEnvironment{sverbatim}{Verbatim}{fontsize=\small}
\DefineVerbatimEnvironment{fverbatim}{Verbatim}{fontsize=\footnotesize}
\DefineVerbatimEnvironment{ssverbatim}{Verbatim}{fontsize=\scriptsize}
\DefineVerbatimEnvironment{tverbatim}{Verbatim}{fontsize=\tiny}

% numbered
\DefineVerbatimEnvironment{nverbatim}{Verbatim}
  {fontsize=\small,numbers=left,xleftmargin=\parindent}
\DefineVerbatimEnvironment{cverbatim}{Verbatim}{fontsize=\small,%
  firstnumber=continue,numbers=left,xleftmargin=\parindent}
\DefineVerbatimEnvironment{nssverbatim}{Verbatim}
  {fontsize=\scriptsize,numbers=left,xleftmargin=\parindent}

% alltt series allowing commands to be used
\DefineVerbatimEnvironment{alltt}{Verbatim}{fontsize=\normalsize,%
  commandchars=\\\{\}}
\DefineVerbatimEnvironment{salltt}{Verbatim}{fontsize=\small,%
  commandchars=\\\{\}}
\DefineVerbatimEnvironment{falltt}{Verbatim}{fontsize=\footnotesize,%
  commandchars=\\\{\}}
\DefineVerbatimEnvironment{ssalltt}{Verbatim}{fontsize=\scriptsize,%
  commandchars=\\\{\}}
\DefineVerbatimEnvironment{talltt}{Verbatim}{fontsize=\tiny,%
  commandchars=\\\{\}}
\endinput
