%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                                                                    %
% CERN foil -- Basic simple form style option for making foils.      %
%                                                                    %
% Loosely based on an idea from Nicole <NICOLE@FRINRA72>             %
%                                                                    %
% Style can ne used by calling it in the documentstyle               %
% \documentstyle[...,cernfoil.sty]{...}                              %
%                                                                    %
% - Original for latex 2.09 1992/93    1.12                          %
% - Version for latex2e     July 1994  2.1                           %
% - fancyheaders.sty --> fancyhdr.sty  2.2 (Oct 1998)                %
%                                                                    %
% Michel Goossens / IT/ASD                                           %
%                                                                    %
% Last Mod.: 30 Oct.    1998  m.g.  13:35  (Version 2.1)             %
%                                                                    %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 
%%
\def\fileversion{2.2}
\def\filedate{1998/10/30}
\def\docdate {1994/07/08}
\NeedsTeXFormat{LaTeX2e}
\ProvidesClass{cernfoil}[\filedate\space\fileversion\space CERN
                          cernfoil class (mg).]
\DeclareOption*{\PassOptionsToClass{\CurrentOption}{article}}
\ProcessOptions
\LoadClass{article}
\RequirePackage{graphicx}
 
% First some useful definitions for getting ``funny'' characters
 
\def\bs{{\rm\tt\char92{}}}  %%%%% backslash         %%%%%
\def\lqb{{\`{}}}            %%%%% left quote brace  %%%%%
\def\rqb{{\'{}}}            %%%%% right quote brace %%%%%
\def\lcb{{\tt\char'173{}}}  %%%%% left brace        %%%%%
\def\rcb{{\tt\char'175{}}}  %%%%% right brace       %%%%%
\def\lsb{{\tt\char'133{}}}  %%%%% left brace        %%%%%
\def\rsb{{\tt\char'135{}}}  %%%%% right brace       %%%%%
\def\lab{{\tt\char'74{}}}   %%%%% left brace        %%%%%
\def\rab{{\tt\char'76{}}}   %%%%% right brace       %%%%%
\def\vsp{{\tt\char32{}}}    %%%%% visual space      %%%%%
\def\vb{{\tt\char'174{}}}   %%%%% vertical bar      %%%%%
 
% Define the title
 
\newsavebox{\Title}
\savebox{\Title}{\Large\null}
 
% Define page layout parameters for A4 paper
 
\setlength{\hoffset}{-13mm}
\setlength{\voffset}{-24mm}
\setlength{\textwidth}{18cm}
\setlength{\oddsidemargin}{0.8cm}
\setlength{\evensidemargin}{0.8cm}
\setlength{\textheight}{24.5cm}
\setlength{\parindent}{0.0cm}
\setlength{\parskip}{0.5cm}
\setlength{\topmargin}{0pt}
\setlength{\headheight}{2.0cm}
\setlength{\headsep}{5mm}
\setlength{\footskip}{1.7cm}
 
%%% Construct the headers and footers using the fancyhdr packages
\RequirePackage{epsfig}% The CERN logo needs it
\RequirePackage{fancyhdr}
\setlength{\headwidth}{19.0cm}
\renewcommand{\headrulewidth}{0pt}
\renewcommand{\footrulewidth}{0pt}
\setlength{\unitlength}{1cm}
\lhead{\begin{picture}(0.00001,0.00001)%
\put(9.0,-13.4){\oval(19,25.6)}\end{picture}%
\raisebox{-2mm}{\includegraphics[width=14mm]{cern15.eps}}}
\rhead{\raisebox{-2mm}{\includegraphics[width=14mm]{cern15.eps}}}
\chead{}
\lfoot{\today}
\cfoot{{\usebox{\Title}\thepage}}
\rfoot{\@author}
%%%%%%%%%%%% Command \tableofcontent %%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\def\Tableofcontents{%
\begin{center}\huge\bf Table of Contents\end{center}
\markboth{Table of Contents}{Table of Contents}
\Large \@starttoc{toc}}
\def\Tabledesmatieres{%
\begin{center}\huge\bf Table des mati\`eres\end{center}
\markboth{TABLE DES MATI\`ERES}{TABLE DES MATI\`ERES}
\starttoc  \@starttoc{toc}}
%%%%%%%%%%%% Command transptittre %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\newcommand{\Trtitle}[1]{\savebox{\Title}{\Large#1-}}
%%%%%%%%%%%% Command transpar %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\newcommand{\Transpar}{\Large\newpage}
%%%%%%%%%%%% Command tr   %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\def\Tr{\protect\Transpar\null\vspace*{-1mm}}
%%%%%%%%%%%% Command tran %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\def\Tran#1{\Tr\protect\typeout{#1}\vspace*{-2mm}
\begin{center}\protect\huge\protect\bf #1\end{center}\vspace{-0.1cm}
\chead{\protect\Large\protect#1}%
\addcontentsline{toc}{section}{#1}}
%%%%%%%%%%%% Command Stitle %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\newcommand{\Stitle}[1]{%
\vspace*{-3mm}\begin{center}\bf#1\end{center}\vspace*{-3mm}%
\addcontentsline{toc}{subsection}{#1}}
%%%%%%%%%%%% Command Exemple %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\newcommand{\Exemples}{Exemples~:\par}
\newcommand{\Exemple}{Exemple~:\par}
\newcommand{\Examples}{Examples~:\par}
\newcommand{\Example}{Example~:\par}

%%%%%%%%% From example style by Joachim Schrod %%%%%%%%%%%%%%
\chardef\escape=0
\chardef\open=1
\chardef\close=2
\chardef\letter=11
\chardef\other=12
\chardef\uscode=\catcode`\_      % top level macro file!
 
\catcode`\_=\letter
\oddsidemargin=0pt
\evensidemargin=\oddsidemargin
\newwrite\example_file
\def\example_name{\jobname.tmp }        % <-- space!
\newdimen\ExampleWidth
      \ExampleWidth=\textwidth
%      \advance\ExampleWidth by \marginparwidth  % stick into margins
      \advance\ExampleWidth by -\columnsep      % between columns
      \divide\ExampleWidth by 2

\def\ExampleSet{%
   \begin{minipage}[t]{\ExampleWidth}%
      \hrule height\z@
      \def\markboth##1##2{}%
      \def\markright##1{}%
      \def\addcontentsline##1##2##3{}%
      \input \example_name
      \par
      \hrule height\z@
   \end{minipage}%
   }
\begingroup
   \catcode`\^^I=\active
   \gdef\@vobeytabs{\catcode`\^^I\active \let^^I\@xobeytab}
   \global\let^^I=\@xobeytab%           % for \write's
\endgroup
\def\@xobeytab{\space\space\space\space\space\space\space\space}

\def\ExampleVerb{%
   \begin{minipage}[t]{\ExampleWidth}%
      \hrule height\z@
      \begingroup
         \parindent\z@
         \rightskip\@flushglue
         \@makeother\"\@verbatim
         \frenchspacing \@vobeyspaces \@vobeytabs
         \input \example_name
         \endverbatim
      \endgroup
      \hrule height\z@
   \end{minipage}%
   }

\def\example{
   \par
   \immediate\openout\example_file\example_name
   \begingroup
      \@makeother\"\let\do\@makeother \dospecials
      \obeylines \obeyspaces
      \@ignoretrue \copy_line
   }

\begingroup
   \catcode`\|=\escape  % | is temporary escape character
   \catcode`\[=\open    % [ and ] are temporary grouping symbols
   \catcode`\]=\close
   \catcode`\{=\other   % these are `other' in verbatim mode
   \catcode`\}=\other
   \catcode`\\=|other
   |gdef|end_of_example[\end{example}]
|endgroup

\begingroup
   \obeylines \gdef\copy_line#1^^M{\write_line{#1}}%
\endgroup
 
\def\write_line#1{%
   \def\next{#1}%
   \ifx \next\end_of_example
      \def\next{\end{example}}% % finish example
   \else
      \ifx \next\empty
         \if@ignore             % ignore empty lines at the beginning
         \else                  % but write them out later
            \immediate\write\example_file{\next}%
         \fi
      \else
         \immediate\write\example_file{\next}%
         \@ignorefalse          % at least one non-empty line written
      \fi
      \let\next\copy_line       % next line of example
   \fi
   \next
   }

\def\endexample{%
   \endgroup
   \immediate\closeout\example_file
   \penalty \predisplaypenalty
   \vskip \abovedisplayskip
   \leftline{\ExampleSet \hskip\columnsep \ExampleVerb}%
   \penalty \postdisplaypenalty
   \vskip \belowdisplayskip
   }

\catcode`\_=\uscode
%%%%%%%%%%%%%%%%%%  end of example style %%%%%%%%%%%%%%%%%%%%%%% 
\pagestyle{fancy}
\sloppy

\endinput
