%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%  Name:     cernart.sty                                          %
%                                                                 %
%  Purpose:  Set LaTeX parameters for CERN preprint               %
%                                                                 %
%  Complete rewrite of CERN classes (May-June 2005)               %
%                                                                 %
%   - special treatment of title page                             %
%   - Basic point size 12pt                                       %
%   - Based on standard LaTeX article.cls                         %
%                                                                 %
%                                                                 %
%  Last mod.: 8 June 2005 MG (Michel Goossens IT/UDS-PUB)         %
%                                                                 %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%
\def\fileversion{3.1}
\def\filedate{8 June 2005}
\def\docdate{8 June 2005}
\typeout{Document Style 'cernprep'. Version <\fileversion>, <\filedate>}
% -------------------------------- identification ---------------------------
\NeedsTeXFormat{LaTeX2e}
\ProvidesClass{cernprep}[2005/06/08]
% ---------------------------  declaration of options --
\DeclareOption*{\PassOptionsToClass{\CurrentOption}{article}}
\ProcessOptions
\LoadClass[12pt,a4paper,twoside]{article}
\renewcommand{\rmdefault}{ptm}
\RequirePackage{graphicx,amsmath,cite,array,tabularx,url}
 
\typeout{Document Class "cernprep" 3.1  8 June 2005}

%%% Customization of visible document elements

\renewcommand\thesection      {\@arabic\c@section}
\renewcommand\thesubsection   {\thesection.\@arabic\c@subsection}
\renewcommand\thesubsubsection{\thesubsection.\@arabic\c@subsubsection}
\renewcommand\theparagraph{\thesubsubsection.\@arabic\c@paragraph}
\renewcommand\baselinestretch{1.}
\renewcommand{\contentsname}{Contents}
\renewcommand{\listfigurename}{List of Figures}
\renewcommand{\listtablename}{List of Tables}
\renewcommand{\refname}{References}
\renewcommand{\indexname}{Index}
\renewcommand{\figurename}{Fig.}
\renewcommand{\tablename}{Table}
\renewcommand{\partname}{Part}
\renewcommand{\appendixname}{Appendix}
\renewcommand{\abstractname}{Abstract}

% Short and long pages

\newcommand{\longpage}[1][1]{\enlargethispage{#1\baselineskip}}
\newcommand{\shortpage}[1][1]{\enlargethispage{-#1\baselineskip}}

%  ****************************************
%  *            Lists                     *
%  ****************************************
%
% Prevent infinite loops
\let\Otemize =\itemize
\let\Onumerate =\enumerate
\let\Oescription =\description
% Zero the vertical spacing parameters
\def\Nospacing{\itemsep=2pt\topsep=0pt\partopsep=0pt\parskip=0pt\parsep=0pt}
% Redefine the environments in terms of the original values
\renewenvironment{itemize}{\vspace*{-3mm}\Otemize\Nospacing}%
                               {\endlist\vspace*{-3mm}}
\renewenvironment{enumerate}{\vspace*{-3mm}\Onumerate\Nospacing}
                               {\endlist\vspace*{-3mm}}
\renewenvironment{description}{\vspace*{-3mm}\Oescription\Nospacing}
                               {\endlist\vspace*{-3mm}}
\renewcommand\labelitemi{\normalfont\textendash}
\renewcommand\labelitemii{\normalfont\textendash}
\renewcommand\labelitemiii{\textasteriskcentered}
\renewcommand\labelitemiv{\textperiodcentered}

%  ****************************************
%  *            PAGE LAYOUT               *
%  ****************************************
%
% All margin dimensions measured from a point one inch from top and side
% of page.
 
% SIDE MARGINS:

\textheight 24cm       % Height of text (including footnotes and figures,
                       % excluding running head and foot).
\textwidth 16cm        % Width of text line.
\topmargin -28pt       % offset of top header from voffset (1 inch)
%\topmargin -48pt       % offset of top header from voffset (1 inch)

%%% pagewidth           = 210 mm = 596 pt
%%% hoffset :           =   1 in =  72 pt
%%% textwidth           = 160 mm = 454 pt

% SIDE MARGINS:  %%%% A4 : pagewidth=160mm 
\if@twoside   % Values for two-sided printing:
      %%% margins : inner     =  30 mm =  86 pt
      %%%           outer     =  20 mm =  56 pt
      %%% \odd/evensidemargin are with respect to hoffset -->
   \oddsidemargin   14pt    %   Left margin on odd-numbered pages.
   \evensidemargin -14pt    %   Left margin on even-numbered pages.
\else         % Values for one-sided printing:
   \oddsidemargin    0pt    %   Note that \oddsidemargin = \evensidemargin
   \evensidemargin   0pt
\fi

\pagestyle{plain}
 
% Define caption layout %%%%%

\setlength\abovecaptionskip{6\p@}
\setlength\belowcaptionskip{4\p@}
\long\def\@makecaption#1#2{%
  \vskip\abovecaptionskip
  \sbox\@tempboxa{{\small #1: #2}}%
  \ifdim \wd\@tempboxa >\hsize
    {\small #1: #2}\par
  \else
    \global \@minipagefalse
    \hbox to\hsize{\hfil\box\@tempboxa\hfil}%
  \fi
  \vskip\belowcaptionskip}

%
%  ****************************************
%  *       Section headings               *
%  ****************************************
%

\newcommand{\@@Section}{\@startsection {section}{1}{\z@}%
                                   {-0.5cm \@plus -1ex \@minus -.2ex}%
                                   {0.3ex \@plus.2ex}%
                                   {\reset@font\normalsize\bfseries}}
\newcommand{\@@Subsection}{\@startsection{subsection}{2}{\z@}%
                                     {-0.5cm \@plus -1ex \@minus -.2ex}%
                                     {0.1ex \@plus .2ex}%
                                     {\reset@font\normalsize\bfseries}}
\renewcommand{\subsubsection}{\@startsection{subsubsection}{3}{\z@}%
                                     {-0.5cm \@plus -1ex \@minus -.2ex}%
                                     {0.1ex \@plus .2ex}%
                                     {\reset@font\normalsize\itshape}}
%
\newcommand{\@@Paragraph}{\@startsection{paragraph}{4}{\z@}%
                                    {3.25ex \@plus1ex \@minus.2ex}%
                                    {-1em}%
                                    {\reset@font\normalsize\bfseries}}
\renewcommand{\subparagraph}{\@startsection{subparagraph}{5}{\parindent}%
                                       {3.25ex \@plus1ex \@minus .2ex}%
                                       {-1em}%
                                      {\reset@font\normalsize\bfseries}}

%%% make footnote robust (if it appears in argument of, e.g., \section)
\let\oldfootnote\footnote
\def\footnote{\protect\oldfootnote}
\RequirePackage{ifthen}

%%% Force section 1 titles in small caps %%%%%%%%%%%%%%%%%%%%%

\let\savesection\@@Section
\def\section{\@ifstar{\sectionstar}{\sectionnormal}}
\newcommand{\sectionstar}[1]{%\typeout{ **** #1 *****}%
                             \savesection*{\scshape\boldmath #1\unboldmath}}
\newcommand{\sectionnormal}[2][!?!]{\ifthenelse
                 {\equal{#1}{!?!}}{%\typeout{ @@@@@@ section #2 @@@@@@@}%
                                   \savesection[{\upshape #2}]%
                              {\scshape\boldmath #2\unboldmath}}
                                  {%\typeout{ @@@@@@ section [#1]#2 @@@@@@@}%
                                   \savesection[{\upshape #1}]%
                              {\scshape\boldmath #2\unboldmath}}}

\let\savesubsection\@@Subsection
\def\subsection{\@ifstar{\subsectionstar}{\subsectionnormal}}
\newcommand{\subsectionstar}[1]{%\typeout{ **** #1 *****}%
                             \savesubsection*{\boldmath #1\unboldmath}}
\newcommand{\subsectionnormal}[2][!?!]{\ifthenelse
                 {\equal{#1}{!?!}}{%\typeout{ @@@@@@ section #2 @@@@@@@}%
                                   \savesubsection[#2]%
                              {\boldmath #2\unboldmath}}
                                  {%\typeout{ @@@@@@ section [#1]#2 @@@@@@@}%
                                   \savesubsection[#1]%
                              {\boldmath #2\unboldmath}}}

\let\saveparagraph\@@Paragraph
\def\paragraph{\@ifstar{\paragraphstar}{\paragraphnormal}}
\newcommand{\paragraphstar}[1]{%\typeout{ **** #1 *****}%
                             \saveparagraph*{\boldmath #1\unboldmath}}
\newcommand{\paragraphnormal}[2][!?!]{\ifthenelse
                 {\equal{#1}{!?!}}{%\typeout{ @@@@@@ section #2 @@@@@@@}%
                                   \saveparagraph[#2]%
                              {\boldmath #2\unboldmath}}
                                  {%\typeout{ @@@@@@ section [#1]#2 @@@@@@@}%
                                   \saveparagraph[#1]%
                              {\boldmath #2\unboldmath}}}



%
%  ****************************************
%  *       Appendix bookkeeping           *
%  ****************************************
%
 
\renewcommand\appendix{\par
  \setcounter{section}{0}%
  \setcounter{subsection}{0}%
  \setcounter{figure}{0}%
  \setcounter{table}{0}%
  \setcounter{equation}{0}%
  \gdef\thesection{\textsc{Appendix~\@Alph\c@section:}}%
  \gdef\thesubsection{\@Alph\c@section.\@arabic\c@subsection}
  \gdef\theequation{\@Alph\c@section.\@arabic\c@equation}
  \@addtoreset {equation}{section}%
  \gdef\thetable{\@Alph\c@section.\@arabic\c@table}%
  \@addtoreset {table}{section}%
  \gdef\thefigure{\@Alph\c@section.\@arabic\c@figure}%
  \@addtoreset {figure}{section}%
}

% 
%  ************************************
%  *   thebibliography environement   *
%  ************************************
%

\setlength\bibindent{1.5em}
\renewenvironment{thebibliography}[1]
     {\section*{\refname}%
      \list{\@biblabel{\@arabic\c@enumiv}}%
           {\settowidth\labelwidth{\@biblabel{#1}}%
            \leftmargin\labelwidth
            \advance\leftmargin\labelsep
            \@openbib@code
            \usecounter{enumiv}%
            \let\p@enumiv\@empty
            \renewcommand\theenumiv{\@arabic\c@enumiv}}%
      \Nospacing
      \sloppy
      \clubpenalty4000
      \@clubpenalty \clubpenalty
      \widowpenalty4000%
      \sfcode`\.\@m}
     {\def\@noitemerr
       {\@latex@warning{Empty `thebibliography' environment}}%
      \endlist}
\renewcommand\newblock{\hskip .11em\@plus.33em\@minus.07em}
\let\@openbib@code\@empty

\iffalse
 
%%%%%%%%%%%%%%%%%%%%%% footnotes %%%%%%%%%%%%%%%%%%%%%
\def\footnoterule{\kern-3\p@
 \hrule width .4\columnwidth
 \kern 2.6\p@}
 
%%%%%%%%%%%% Environment makefntext %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\long\def\@makefntext#1{\parindent=\z@
\begin{list}{}%
   {\labelwidth1.5em\leftmargin\labelwidth% set global width
    \labelsep3pt%  horizontal separation between term and item
    \itemsep0pt%   vertical separation between two items
    \parsep0pt%    vertical separation two paragraphs in an item
    \topsep0pt%    vertical separation text/list
    \footnotesize}
    \item [\hfill $^{\mathrm{\@thefnmark)}}$] #1\end{list}}% ***** end of makefntext
 
%%%%%%%%%%%% Environment Figlist %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\newenvironment{Figlist}[1]{% Give highest figure number as parameter
\vskip2mm\begin{center}{\bf FIGURE CAPTIONS}\end{center}
\begin{list}{\bf Fig.\hfill\arabic{figure} : }{\usecounter{figure}
    \settowidth{\labelwidth}{\bf Fig . #1 : }% define global width
    \leftmargin\labelwidth \labelsep0pt
    \itemsep0pt plus 0.1ex minus 0.1ex
    \parsep0pt plus 0.1ex minus 0.1ex
    \topsep\baselineskip}}%
{\end{list}\setcounter{figure}{0}% Reset figure counter
}% ***** end of environment{Figlist} ****

%%%%%%%%%%%% Environment CERNfig %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\newenvironment{CERNfig}{\begingroup % figures, one per page
\def\@makecaption##1##2{\hbox to\hsize{\hfil##1\hfil}}}%
{\endgroup}
% ***** end of environment{CERNfig} ****
 
%%%%%%%%%%%% Environment Tablist %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\newenvironment{Tablist}[1]{% Give highest table number as parameter
\vskip2mm\begin{center}{\bf TABLE CAPTIONS}\end{center}
\begin{list}{\bf Tab.\hfill\arabic{table} : }{\usecounter{table}
    \settowidth{\labelwidth}{\bf Fig . #1 : }% define global width
    \leftmargin\labelwidth \labelsep0pt
    \itemsep0pt plus 0.1ex minus 0.1ex
    \parsep0pt plus 0.1ex minus 0.1ex
    \topsep\baselineskip}}%
{\end{list}\setcounter{table}{0}% Reset table counter
}% ***** end of environment{Tablist} ****
 
%%%%%%%%%%%%%%%%%%%%% TH Division specifics %%%%%%%%%%%%%%%%%%%%
 
% Definition of environment "THtitle" (Title page for TH Division)
\def\Pubnum#1{\def\@Pubnum{#1}}\def\@Pubnum{CERN--TH.xxxx/91}
\def\Pubnumtwo#1{\def\@Pubnumtwo{#1}}\def\@Pubnumtwo{}
\def\Pubnumtthree#1{\def\@Pubnumthree{#1}}\def\@Pubnumthree{}
\def\Pubdate#1{\def\@Pubdate{#1}}\def\@Pubdate{\today}
\newenvironment{THtitlepage}{%
  \thispagestyle{thfirst}\pagenumbering{arabic}%
  \def\title##1{\begin{center}\large\mbox{}\\[2\baselineskip]
                \uppercase{##1}\\[2\baselineskip]\end{center}}
  \def\author##1{\begin{center}\large##1\\[2\baselineskip]\end{center}}
  \renewenvironment{abstract}{% Definition of abstract
  \begin{center}\large \mbox{}\\[2\baselineskip]
  ABSTRACT\\[\baselineskip]\end{center}}%
  {\par\vspace*{2\baselineskip}}
}% End of beginning of THtitlepage
{\newpage\thispagestyle{empty}\mbox{}\newpage% Empty page
  \setcounter{footnote}{0}\setcounter{page}{1}\pagestyle{plain}
  \def\Pubnum##1{}\def\@Pubnum{}\def\Pubnumtwo##1{}\def\@Pubnumtwo{}
  \def\Pubnumthree##1{}\def\@Pubnumthree{}\def\Pubdate##1{}\def\@Pubdate{}
  \def\author##1{}\def\title##1{}
}% End of title page
 
% Definition of running titles for Theory Division
\def\ps@thfirst{\let\@mkboth\@gobbletwo
  \def\@evenhead{}\def\@evenfoot{}% Nothing for even pages
  \def\Rule{\rule[-1.ex]{0ex}{3ex}}
  \def\@oddhead{\hfill\raisebox{0pt}[0pt][0pt]{\rm
   \vtop{\hbox{\@Pubnum\Rule}
       \ifx\@Pubnumtwo\@empty\else\hbox{\@Pubnumtwo\Rule}\fi
       \ifx\@Pubnumthree\@empty\else\hbox{\@Pubnumthree\Rule}\fi}}%
        }%     Running header
  \def\@oddfoot{\raisebox{0pt}[0pt][0pt]{\rm
   \vbox{\hbox{\@Pubnum}\hbox{\@Pubdate}}}\hfill
        }%     Running footer
  \def\sectionmark##1{}
  \def\subsectionmark##1{}
}% First page for Th Division
 
%%%%%%%%%%%%%%%%%%%%% section headings %%%%%%%%%%%%%%%%%%%%%%%%%%

\def\section{\@startsection {section}{1}{\z@}%
{ 1\baselineskip plus  .5\baselineskip minus  .25\baselineskip}%
{+0.1pt plus +0.1pt minus +0.1pt}{\reset@font\normalsize\bfseries}}
 
\def\subsection{\@startsection{subsection}{2}{\z@}%
{ 1\baselineskip plus  .5\baselineskip minus  .25\baselineskip}%
{+0.1pt plus +0.1pt minus +0.1pt}{\reset@font\normalsize\bfseries}}
 
\def\subsubsection{\@startsection{subsubsection}{3}{\z@}%
{ 1\baselineskip plus  .5\baselineskip minus  .25\baselineskip}%
{+0.1pt plus +0.1pt minus +0.1pt}{\reset@font\normalsize\itshape}}
\fi
 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% \begin{titlepage}
%     \docnum{CERN--EP/90--xx}
%     \date{}
%     \title{ first  line \\
%             second line \\
%             etc...}
%     \author{B.B.Auth\Instref{xx} M.M.~Auth2\Bothref{I1}{A2}
%             C.D.user\Instref{yy} ...}
% Submitted{}
% collaboration{}
% conference{}
% note{}
% dedication{}
%     \Instfoot{xx}{text text}
%     \Instfoot{yy}{text text}
% \end{titlepage}
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%% title page %%%%%%%%%%%%%%%%%%%%%%%%%5
\def\maketitle{% Dummy maketitle
\typeout{Dummy maketitle --- Use titlepage instead}}
% Definition of environment "titlepage"
\def\titlepage{\clearpage
\setcounter{footnote}{0}\setcounter{page}{1}\pagestyle{empty}%
% CERN title
\kern1mm\begin{center}
\mbox{\ifcase\@ptsize \large\or \large\or \normalsize\fi%
EUROPEAN ORGANIZATION FOR NUCLEAR RESEARCH}
\end{center}
\vskip5mm\@normalsize}% End of \titlepage tag
% Document number (flushright)
\def\docnum#1{\hbox to \hsize{\hskip123mm\hbox{#1}\hss}}
% Date (flushright)
\def\date#1{\edef\@temp{#1}\ifx\@temp\@empty\def\@temp{\today}\fi
\hbox to \hsize{\hskip123mm\hbox{\@temp}\hss}}
% Submitted{}
\def\submitted#1{\vskip1em\begin{center}\it#1\end{center}}
% collaboration{}
\def\collaboration#1{\vskip1em\begin{center}\it#1\end{center}}
% conference{}
\def\conference#1{\vskip1em\begin{center}\it#1\end{center}}
% note{}
\def\note#1{\vskip1em\begin{center}\it#1\end{center}}
% dedication{}
\def\dedication#1{\vskip1em\begin{center}\it#1\end{center}}
% Title
\def\title#1{\vskip1em\begin{center}\normalsize\bf#1\end{center}\vskip1.5em}
% Author
%\def\@makefnmark{\hbox to 0pt{$^{\@thefnmark)\,}$\hss}}
\def\@makefnmark{\hbox{$^{\@thefnmark)}$}}
\def\author#1{%% Treat the list of authors
\setcounter{footnote}{0}\def\@currentlabel{}%
\begingroup\def\thefootnote{\arabic{footnote}}
\def\@makefnmark{\hbox{$^{\rm\@thefnmark)}$}}
\global\@topnum\z@ \begin{center}{\lineskip.5em
\begin{tabular}[t]{c}#1\end{tabular}\par}
\end{center}\par\vskip1.5em\@thanks\endgroup}
%
\newenvironment{Authlist}{\center}{\endcenter}
% Abstract
\def\abstract{\begin{center}{\bf Abstract}\\[\baselineskip]%
\end{center}\quotation\small}
\def\endabstract{\endquotation\par}
%
%%%%%%%%%%%% Institute definitions  %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\@ifundefined{c@instfoot}{\newcounter{instfoot}}{}
\def\Iref#1{$^{\Inst{#1})}$}   \let\Instref=\Iref
\def\Inst#1{\@ifundefined{r@#1}{{\bf ??}}%
{\edef\@tempa{\@nameuse{r@#1}}\expandafter\@car\@tempa \@nil\null}}
%
%%AS If we found `Instfoot' inside `Authlist' env, we change the
%    formatting.
%
\def\Instfoot#1#2{\def\@temp{Authlist}%
\ifx\@temp\@currenvir
    \par #2 \\[2ex]%
\else
    \refstepcounter{instfoot}\label{#1}%
    \xdef\@thefnmark{\arabic{instfoot}}\@footnotetext{#2}%
\fi
}
%
%%%%%%%%%%%% Anotation definitions  %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%\@ifundefined{c@anotfoot}{\newcounter{anotfoot}}{}
%\@ifundefined{mathrm}{\newcommand{\mathrm}[1]{{\rm#1}}}{}
\def\Aref#1{$^{\mathrm{#1})}$} \let\Anotref=\Aref
\def\Anotfoot#1#2{\xdef\@thefnmark{#1}\@footnotetext{#2}}
%
%%%%%%%%%%%% Anotation references   %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\def\AAref#1#2{$^{\mathrm{#1,#2)}}$}       \let\AnotAnotref=\AAref
\def\IAref#1#2{$^{\Inst{#1},\mathrm{#2)}}$}\let\InstAnotref=\IAref
\def\IIref#1#2{$^{\Inst{#1},\Inst{#2})}$}  \let\InstInstref=\IIref
\def\IIIref#1#2#3{$^{\Inst{#1},\Inst{#2},\Inst{#3})}$}
\def\IIAref#1#2#3{$^{\Inst{#1},\Inst{#2},\mathrm{#3)}}$}
%%%%%%%%%%%% Annospec environment   %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\newenvironment{Annospec}[1]{% Give width for offset of text
\vskip2mm\bgroup
%\def\@makefnmark{\hbox{$^{\mathrm{\@thefnmark)}}$}}
\long\def\@makefntext##1{\parindent=\z@
\begin{list}{}%
   {\labelwidth=#1\leftmargin\labelwidth% set global width
    \labelsep3pt%  horizontal separation between term and item
    \itemsep0pt%   vertical separation between two items
    \parsep0pt%    vertical separation two paragraphs in an item
    \topsep0pt%    vertical separation text/list
    \footnotesize}
    \item [\hfill $^{\mathrm{\@thefnmark)}}$] ##1\end{list}}}% ***** end of makefntext
{\egroup}% ***** end of environment{Annospec} *****
 
 
% End of titlepage
\def\endtitlepage{%% Reset counters
\setcounter{footnote}{0}\let\titlepage\relax\vfill
\cleardoublepage\pagestyle{plain}\pagenumbering{arabic}\setcounter{page}{3}%
\gdef\@thanks{}\gdef\@author{}\gdef\@title{}\let\thanks\relax}
% Local CERN stuff
 
\newcommand{\bra}[1]{\left\langle #1\right|} % <bra|
\newcommand{\ket}[1]{\left| #1\right\rangle} % |ket>
\newcommand{\braket}[2]{\left\langle#1 | #2\right\rangle} % <bra|ket>
 
\renewcommand{\bottomfraction}{0.3}
\renewcommand{\topfraction}{0.85}
\renewcommand{\textfraction}{0.15}
\setcounter{topnumber}{5}
\setcounter{totalnumber}{6}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%  Equations                                                       %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

\allowdisplaybreaks

\endinput
 
%% \CharacterTable
%%  {Upper-case    \A\B\C\D\E\F\G\H\I\J\K\L\M\N\O\P\Q\R\S\T\U\V\W\X\Y\Z
%%   Lower-case    \a\b\c\d\e\f\g\h\i\j\k\l\m\n\o\p\q\r\s\t\u\v\w\x\y\z
%%   Digits        \0\1\2\3\4\5\6\7\8\9
%%   Exclamation   \!     Double quote  \"     Hash (number) \#
%%   Dollar        \$     Percent       \%     Ampersand     \&
%%   Acute accent  \'     Left paren    \(     Right paren   \)
%%   Asterisk      \*     Plus          \+     Comma         \,
%%   Minus         \-     Point         \.     Solidus       \/
%%   Colon         \:     Semicolon     \;     Less than     \<
%%   Equals        \=     Greater than  \>     Question mark \?
%%   Commercial at \@     Left bracket  \[     Backslash     \\
%%   Right bracket \]     Circumflex    \^     Underscore    \_
%%   Grave accent  \`     Left brace    \{     Vertical bar  \|
%%   Right brace   \}     Tilde         \~}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
