% Change history: - \@date used in title and running footer
%                      i.e. \date can change date printed from \today.
%                 - allow title without address (test on \@address).
%                 - rotate landscape 90 clockwise, to show correctly
%                      with ghostview (upright).
%                 MG July 4th 10:22
% -------------------------------- identification ---------------------------
\NeedsTeXFormat{LaTeX2e}
\ProvidesClass{cernsem}[1996/07/05 CERN seminar extensions]
% --------------------------------  initial code ----------------------------
\DeclareOption*{\PassOptionsToClass{\CurrentOption}{seminar}}
% ----------------------------  execution of options ------------------------
\ProcessOptions
% --------------------------------package loading ---------------------------
\LoadClass{seminar}                                  % the real code
% --------------------------------  main code -------------------------------
%
% might as well as have nice PS effects like rounded box corners
% we need logos in eps form. load PStricks and LaTeX color package.
\RequirePackage[dvipsnames]{xcolor}
\RequirePackage{pstricks}
\altcolormode
%\input{semcolor.sty}
% pick up van Zandt's other tools
\input{fancybox.sty}
%
% European paper is A4 
\def\paperwidth{210mm}
\def\paperheight{297mm}
\input sem-page.sty
\input{slidesec.sty}
%
% --------------------------------------------------
% For plain CERN use, ie A4 paper and dvips driver.
\def\printlandscape{\special{papersize=297mm,210mm}}
%
% careful here; limited by size colour printer can work to.
\slidewidth 220mm
\slideheight 156mm
\slideframesep 8mm
\def\slideleftmargin{12mm}
\def\sliderightmargin{12mm}
\def\slidetopmargin{15mm}
\def\slidebottommargin{15mm}
%
%---------------------------------------------------------------
% I like an address in my titles
%
\renewcommand{\slidemaketitle}{%
  \null
  \begin{center}
    \def\baselinestretch{1}\large\small
    {\Large\bfseries \@title \par}%
    {\bfseries \lineskip .5em
\begin{tabular}[t]{c}
{\large\@author}
\ifx\@address\@empty\else\\\@address\fi\relax
\end{tabular}\par}%
    \vskip .5em
    {\large \@date}%
  \end{center}%
  \par\vskip .5em}
\def\address#1{\gdef\@address{#1}}
\gdef\@address{}

%----------------------------------------------------
% headings; make a drop shadow box
%----------------------------------------------------
\def\@@empty{}
\renewcommand{\makeslideheading}[1]{%
	\gdef\theslideheading{#1}%
	\def\@@foo{#1}%
	\ifx\@@foo\@@empty\else
		\begin{Sbox}
		\bgroup
                 \large\bfseries\begin{Bcenter}#1\end{Bcenter}%
                \egroup
                \end{Sbox}
             \centerline{\shadowbox{\TheSbox}}
             \vspace{1ex minus 1ex}
        \fi
\SlideFront}

%------------------------------------------------
% slide styles
%-------------------------------------------------
% CERN
%----------------------------------
% plain CERN; just marks and date
\newpagestyle{cern}%
{{\color{black}\small{\bfseries +} \hfil \today \hfil  {\bfseries+}}}
{{\color{black}\small{\bfseries +} \hfil \thepage\hfil {\bfseries+}}}%
%
% with section headings and logo
%
% load the CERN logo as a header file, so that we don't reload
% the whole file for every page.
\special{header=cernlogo.pro}
\special{! /landplus90 true store}
%
\newpagestyle{cernsections}%
{{\color{black}\small
      \raisebox{-0ex}[0mm][0mm]{\makebox[0mm]{%
                 \special{" .5 .5 .8 0. logocrn}}}%
 \hfil {\bfseries \@title} \hfil 
      \raisebox{-0ex}[0mm][0mm]{\makebox[0mm]{%
                 \special{" .5 .5 -1.1 0. logocrn}}}%
}}
{{\small\color{black}\makebox[0mm][l]{\@date} \hfil\@author \hfil\thepage}}
%
\newslideframe{cern}{{\SlideFront
\boxput(-0.7,-1.11){\psframebox[%
linecolor=black,fillcolor=green,fillstyle=solid]{%
\hbox{{\normalsize\sffamily\textcolor{black}{\Semlabel}}}}}{#1}%
\color{black}}}

%

%---------------------------------------------
% make it easy to do coloured backgrounds and text
%
\def\everyslide{\SlideFront}
\def\theslideheading{}
\def\thechapterheading{}
%
\def\SlideColours#1#2{%
 \gdef\SlideFront{\color{#1}}%
 \slideframe{\Framedefault}%
 \slideframe*[\psset{fillcolor=#2,fillstyle=solid}]{scplain}%
}
%
% defaults
\pagestyle{cernsections}
\slideframe{cern}
\def\Framedefault{cern}
%
\def\blackandwhite{\SlideColours{black}{white}}
\blackandwhite
%--------------------------------------------------------
% shorthand for slides
\newenvironment{Slide}[2][]{\begin{slide}
\slideheading[#1]{#2}\raggedright}{\end{slide}}
%
% Portrait version
\newenvironment{PSlide}[2][]{\begin{slide*}
\slideheading[#1]{#2}\raggedright}{\end{slide*}}
%
% needed because of xcomment.sty
\addtoslidelist{Slide}
\addtoslidelist{PSlide}
%
% rotated headers for consistency of output
\rotateheaderstrue
\raggedright
\centerslidesfalse
\providecommand{\Semlabel}{CERN}
\typeout{loading user configuration of CERN seminar class}
\InputIfFileExists{cernsem.cfg}{}
\endinput



