%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                                                                    %
%  Style file for preparing papers for the 1995 CERN School of Comp. %
%  in Arles (August 1995)                                            %
%                                                                    %
%  Corresponds to the instructions by the organizing committee,      %
%  as distributed to the contributors. It is based on                %
%  the article style      using 12pt Times-Roman for the text font   %
%                                                                    %
%  Author : Michel Goossens/CERN-CN                                  %
%                                                                    %
%  Last Mod:  14 Mar. 1995 mg                                        %
%                                                                    %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\def\fileversion{1.0}
\def\filedate{1996/02/15}
\def\docdate {1996/02/15}
\NeedsTeXFormat{LaTeX2e}
\ProvidesClass{csc96}[\filedate\space CSC96 class]
\DeclareOption*{\PassOptionsToClass{\CurrentOption}{article}}
\ProcessOptions
\LoadClass[11pt]{article}
\pagestyle{empty}
\@twosidefalse
%   *****  Global definitions for page layout *****
\hoffset-1in
\voffset-1in
%\topskip0pt
\oddsidemargin35mm\evensidemargin35mm\marginparwidth25mm
\marginparsep 0pt
\topmargin 2cm
\headheight 0pt
\headsep 0pt
\footskip 30pt
\textwidth 15cm
\setlength{\parindent}{1cm}
\parskip 0pt
\textheight=240mm
\topmargin=35mm
\headsep=0pt
\headheight=0pt
%%%
%%% Don't print the page numbers, but  mark the page numbers with soft pencil
%%% on the reverse side.
%%%
%%%                              General format
%%%
%%% If you  use LaTeX  to produce your paper, you should  use the  style file
%%% which you will  find at the end  of this message.  This  will insure that
%%% the overall aspect of all papers will be the same.
%%%
%%% If  you use  another text processing system,  then you should observe the
%%% following in order to make your paper  look as similar as possible to the
%%% ones produced in LaTeX:
%%%
%%% Title: in 14pts bold Times-Roman, centered (do not use upper case letters
%%% for the entire title).
%%%
%%% Author(s): 12pts Helvetica, flush left
%%%
%%% Institution: 12pts Helvetica-Oblique, fhush left
%%%
%%% Abstract: in 11pts Times-Roman, 14cm wide, centered
%%%
%%% Text: in 12pts Times-Roman, the text must be inside a box
%%% 160 (wide)x240 (high) mm, page numbers should be removed from the
%%% document.
%%%
%%% Figures:  should be  numbered  consecutively with  arabic numbers.
%%% captions should be  placed immediately under the figure and  set in
%%% 10pts Helvetica
%%% \def\thefigure{\arabic{figure}}
%%%
%%% Tables: should be numbered with roman numbers.
%%%
\def\thetable{\Roman{table}}
\long\def\@makecaption#1#2{
 \vskip 10pt
 \setbox\@tempboxa\hbox{{\sffamily\footnotesize\textbf{#1:} #2}}
 \ifdim \wd\@tempboxa >\hsize \unhbox\@tempboxa\par \else \hbox
to\hsize{\hfil\box\@tempboxa\hfil}
 \fi}
%%% Formulae: should  have a number  within normal brackets (ex.  (5)), flush
%%% with the right margin.
%%%
%%% Bibiographic references should  be made with a number  in square brackets
%%% ([17]) and listed at the end of the paper.
%%%
%%%                                   LaTex
%%%
%
% Definition of environment "titlepage"
\def\titlepage{\clearpage%
\setcounter{footnote}{0}\setcounter{page}{1}%
   \let\save@thefootnote=\thefootnote
   \let\save@makefnmark=\@makefnmark
   \def\thefootnote{\fnsymbol{footnote}}%
   \def\@makefnmark{\hbox
       to2mm{$\m@th^{\@thefnmark}$\hss}}%
\kern1mm %???
}% End of \titlepage tag
\def\Institution#1{{\par\itshape #1\\[2mm]}}
% conference{}
\def\conference#1{}
% note{}
\def\note#1{\vskip1em{\it#1\par}}
% dedication{}
\def\Dedication#1{\vskip1em{\it#1\par}}
% Title
\def\title#1{\begin{flushleft}\large\sffamily\bfseries #1
             \end{flushleft}\vskip1em}
\RequirePackage{url}
\RequirePackage{array}
% bibliography list
\def\@biblabel#1{\makebox[10mm][l]{\hspace*{2mm}#1\hfil}}
%%%%%%%%%%%%%%%%%%%       ^^^^ fixed width------------------------+
\renewenvironment{thebibliography}[1]%                            |
     {\section*{\refname             %                            |
        \@mkboth{\uppercase{\refname}}{\uppercase{\refname}}}%    |
      \list{\@biblabel{\arabic{enumiv}}}%                         |
           {\settowidth\labelwidth{10mm}%<<<<<<<< fixed width-----+
            \labelsep0mm%
            \leftmargin\labelwidth
            \usecounter{enumiv}%
            \let\p@enumiv\@empty
            \renewcommand{\theenumiv}{\arabic{enumiv}}}%
        \renewcommand{\newblock}{\hskip .11em \@plus.33em \@minus.07em}%
      \sloppy\clubpenalty4000\widowpenalty4000%
      \sfcode`\.=\@m}
     {\def\@noitemerr
       {\@latex@warning{Empty `thebibliography' environment}}%
      \endlist}
% Author and Institutes
% \begin{Authinst}
% auth1 & Inst1 \\
% auth2 & Inst2 \\
% auth3 & Inst3 \\
% \end{Authinst}
\newenvironment{Authinst}{\par\begin{tabular}{%
                          @{}>{\sffamily}p{32mm}%
                          @{}>{\sffamily\itshape}p{100mm}}}
                         {\end{tabular}\par}
%
% Abstract
\newenvironment{Abstract}
  {\par\vskip1ex\list{}{\listparindent 0pt\small
    \itemindent=0pt\relax
    \leftmargin=1cm\relax
    \rightmargin\leftmargin \parsep \z@ plus\p@}
    \item[]{\sffamily\small\abstractname}\\[1ex]
    \item[]\ignorespaces}
  {\endlist}
%
\def\Keywords#1{{\small\par\vspace*{1pt}\par\noindent
   \hspace*{10mm}\begin{tabular}{@{}lp{12cm}}
                   \sffamily Keywords: & #1
                 \end{tabular}}\par}
\def\endtitlepage{%% Reset counters
\@thanks{}%
\let\thefootnote=\save@thefootnote
\let\@makefnmark=\save@makefnmark
\setcounter{footnote}{0}\let\titlepage\relax\vskip 3mm\upshape
\gdef\@author{}\gdef\@title{}\global\let\thanks\relax
\global\let\@thanks\relax}
 
% The section levels are defined with the help of the
% \Lcs{@startsection} command, defined in \LaTeX{} as follows:
%
% \begin{verbatim}
% \@startsection {NAME}{LEVEL}{INDENT}{BEFORESKIP}{AFTERSKIP}{STYLE}
%            optional * [ALTHEADING]{HEADING}
%    Generic command to start a section.
%    NAME       : e.g., 'subsection'
%    LEVEL      : a number, denoting depth of section -- e.g., chapter=1,
%                 section = 2, etc.  A section number will be printed if
%                 and only if LEVEL < or = the value of the secnumdepth
%                 counter.
%    INDENT     : Indentation of heading from left margin
%    BEFORESKIP : Absolute value = skip to leave above the heading.
%                 If negative, then paragraph indent of text following
%                 heading is suppressed.
%    AFTERSKIP  : if positive, then skip to leave below heading,
%                       else - skip to leave to right of run-in heading.
%    STYLE      : commands to set style
%  If '*' missing, then increments the counter.  If it is present, then
%  there should be no [ALTHEADING] argument.  A sectioning command
%  is normally defined to \@startsection + its first six arguments.
% \end{verbatim}
%
\def\section{\@startsection {section}{1}{\z@}{-2.5ex plus-1ex minus
    -.2ex}{2.3ex plus.2ex}{\reset@font\sffamily\large\bfseries}}
\def\subsection{\@startsection{subsection}{2}{\z@}{-2.25ex plus-1ex
    minus-.2ex}{1.5ex plus.2ex}{\reset@font\normalsize
                                \sffamily\bfseries}}
\def\subsubsection{\@startsection{subsubsection}{3}{\z@}{-2.25ex plus
 -1ex minus-.2ex}{1.5ex plus.2ex}{\reset@font\normalsize
                                \sffamily\mdseries}}
\def\@seccntformat#1{\hbox to 0pt{\hss\csname the#1\endcsname\quad}}
%
%  Dense lists
%
\def\@listI{%
            \leftmargin10mm%
            \labelsep5mm%
            \labelwidth\leftmargin
            \advance\labelwidth-\labelsep
            \parsep \z@
            \topsep 0\p@ \@plus\p@
            \itemsep 0\p@ \@plus1\p@}
\let\@listi\@listI
\@listi
\def\@listii {\leftmargin10mm%
              \labelsep   5mm%
              \labelwidth\leftmarginii
              \advance\labelwidth-\labelsep
              \topsep    0\p@ \@plus\p@
              \parsep    \z@
              \itemsep   \z@ \@plus\p@}
\def\@listiii{\leftmargin10mm%
              \labelsep   5mm%
              \labelwidth\leftmarginiii
              \advance\labelwidth-\labelsep
              \topsep    0\p@ \@plus\p@
              \parsep    \z@
              \partopsep \z@ \@plus\p@
              \itemsep   \z@ \@plus\p@}
\def\@listiv {\leftmargin10mm%
              \labelsep   5mm%
              \labelwidth\leftmarginiv%
              \advance\labelwidth-\labelsep
              \topsep    0\p@ \@plus\p@
              \parsep    \z@
              \itemsep   \z@ \@plus\p@}
\def\@listv  {\leftmargin10mm%
              \labelsep   5mm%
              \labelwidth\leftmarginv
              \advance\labelwidth-\labelsep%
              \topsep    0\p@ \@plus\p@
              \parsep    \z@
              \itemsep   \z@ \@plus\p@}
\def\@listvi {\leftmargin10mm%
              \labelsep   5mm
              \labelwidth\leftmarginvi
              \advance\labelwidth{-\labelsep}%
              \topsep    0\p@ \@plus\p@
              \parsep    \z@
              \itemsep   \z@ \@plus\p@}
%
%
%  Select the fonts
%
\renewcommand{\rmdefault}{ptm}
\renewcommand{\sfdefault}{phv}
\raggedright
\endinput
